@@ -44,7 +44,7 @@ def configure_dll():
         return
 
     min_runtime_version_major = 4
-    min_runtime_version_minor = 0
+    min_runtime_version_minor = 1
     min_runtime_version_patch = 0
 
     if os.name == "nt":
@@ -312,6 +312,14 @@ def configure_dll():
     _cdll.seekcamera_set_color_palette.restype = ctypes.c_int32
     _cdll.seekcamera_set_color_palette.argtypes = [ctypes.c_void_p, ctypes.c_int32]
 
+    # seekcamera_set_color_palette_data
+    _cdll.seekcamera_set_color_palette_data.restype = ctypes.c_int32
+    _cdll.seekcamera_set_color_palette_data.argtypes = [
+        ctypes.c_void_p,
+        ctypes.c_int32,
+        ctypes.POINTER(CSeekCameraColorPaletteDataEntry * 256),
+    ]
+
     # seekcamera_get_agc_mode
     _cdll.seekcamera_get_agc_mode.restype = ctypes.c_int32
     _cdll.seekcamera_get_agc_mode.argtypes = [
@@ -343,7 +351,7 @@ def configure_dll():
 
     # seekcamera_set_temperature_unit
     _cdll.seekcamera_set_temperature_unit.restype = ctypes.c_int32
-    _cdll.seekcamera_get_temperature_unit.argtypes = [ctypes.c_void_p, ctypes.c_int32]
+    _cdll.seekcamera_set_temperature_unit.argtypes = [ctypes.c_void_p, ctypes.c_int32]
 
     # seekcamera_shutter_trigger
     _cdll.seekcamera_shutter_trigger.restype = ctypes.c_int32
@@ -459,6 +467,15 @@ def configure_dll():
     _cdll.seekframe_get_header.argtypes = [ctypes.c_void_p]
 
 
+class CSeekCameraColorPaletteDataEntry(ctypes.Structure):
+    _fields_ = [
+        ("b", ctypes.c_uint8),
+        ("g", ctypes.c_uint8),
+        ("r", ctypes.c_uint8),
+        ("a", ctypes.c_uint8),
+    ]
+
+
 class CSeekCameraFrameHeader(ctypes.Structure):
     _pack_ = 1
     _fields_ = [
@@ -792,6 +809,12 @@ def cseekcamera_set_color_palette(camera, palette):
     return _cdll.seekcamera_set_color_palette(camera.pointer, ctypes.c_int32(palette))
 
 
+def cseekcamera_set_color_palette_data(camera, palette, palette_data):
+    return _cdll.seekcamera_set_color_palette_data(
+        camera.pointer, ctypes.c_int32(palette), ctypes.byref(palette_data)
+    )
+
+
 def cseekcamera_get_agc_mode(camera):
     mode = ctypes.c_int32()
     status = _cdll.seekcamera_get_agc_mode(camera.pointer, ctypes.byref(mode))
