@@ -108,8 +108,8 @@ class SeekCameraFirmwareVersion(object):
 class SeekCameraAppResourcesRegion(IntEnum):
     """Types of app resource regions.
 
-    App resource regions are memory regions on the device that are reserved for customer
-    use.
+    App resource regions are memory regions on the device that are reserved for
+    customer use.
 
     Attributes
     ----------
@@ -166,6 +166,11 @@ class SeekCameraColorPalette(IntEnum):
     AMBER = 6
     HI = 7
     GREEN = 8
+    USER_0 = 9
+    USER_1 = 10
+    USER_2 = 11
+    USER_3 = 12
+    USER_4 = 13
 
     def __str__(self):
         return self.name
@@ -174,6 +179,120 @@ class SeekCameraColorPalette(IntEnum):
         return "SeekCameraColorPalette({})".format(self.value)
 
 
+class SeekCameraColorPaletteData(object):
+    """Collection of color values used to colorize a thermal image.
+
+    Each entry represents a component of a pixel. The values should be in ascending
+    order going from coldest to hottest temperature. It has 256 distinct entries.
+    Each entry is a tuple of color channels ordered as (b, g, r, a).
+
+    Examples
+    --------
+    Creating a new color palette data object with default data (all zeros).
+    >>> palette_data = SeekCameraColorPaletteData()
+
+    Iterating the values of a color palette data object.
+    >>> for index, value in enumerate(palette_data): print(value)
+
+    Slicing a color palette object.
+    >>> palette_data[1:4] = [(255, 0, 0, 0), (0, 255, 0, 0), (0, 0, 255, 0)]
+    >>> print(palette_data[1:4])
+    """
+
+    def __init__(self, data=None):
+        """Creates a color palette data object.
+
+        Parameters
+        ----------
+        data: Optional[Iterable[Tuple[int, int, int, int]]]
+            Collection of tuples that specify the color values for the color palette.
+            It should have length 256; the tuples should be specified in (b, g, r, a)
+            order.
+        """
+        if data is None:
+            data = [(0, 0, 0, 0)] * 256
+
+        self._data = data
+        self._data_iter = 0
+
+    def __repr__(self):
+        return "SeekCameraColorPaletteData({})".format(self._data)
+
+    def __iter__(self):
+        """Iterates through the color values in the color palette data.
+
+        Returns
+        -------
+        SeekCameraColorPaletteData
+            Reference to the color palette data object to iterate.
+        """
+        self._data_iter = 0
+        return self
+
+    def __next__(self):
+        """Gets the next color value in the current iteration.
+
+        Returns
+        -------
+        Tuple[int, int, int, int]
+            The next color palette value in (b, g, r, a) order.
+
+        Raises
+        ------
+        StopIteration
+            If at the end of the collection.
+        """
+        if self._data_iter >= len(self):
+            raise StopIteration
+
+        result = self._data[self._data_iter]
+        self._data_iter += 1
+        return result
+
+    def __getitem__(self, key):
+        """Gets an color value or slice of color values.
+
+        Parameters
+        ----------
+        key: Union[slice, int]
+            Either a slice or a single index used to get the color values.
+
+        Returns
+        -------
+        Union[List[Tuple[int, int, int, int]], Tuple[int, int, int, int]]
+            Either a slice of color values or a single color value.
+        """
+        if isinstance(key, slice):
+            return self._data[key.start : key.stop : key.step]
+        else:
+            return self._data[key]
+
+    def __setitem__(self, key, data):
+        """Sets an color value or slice of color values.
+
+        Parameters
+        ----------
+        key: Union[slice, int]
+            Either a slice or a single index used to set the color values.
+        data: Union[List[Tuple[int, int, int, int]], Tuple[int, int, int, int]]
+            Either a slice of color values or a single color value.
+        """
+        if isinstance(key, slice):
+            self._data[key.start : key.stop : key.step] = data
+        else:
+            self._data[key] = data
+
+    def __len__(self):
+        """Gets the number of color values in the color palette data.
+
+        Returns
+        -------
+        int
+            Number of color values in the color palette data.
+        """
+        return len(self._data)
+
+
 class SeekCameraAGCMode(IntEnum):
     """Types of automated gain correction (AGC) modes.
 
@@ -207,8 +326,8 @@ class SeekCameraShutterMode(IntEnum):
         enabled, the user does not need to manually trigger the shutter. This is the
         default shuttering mode.
     MANUAL: int
-        Shutter mode type case for manual shuttering. When manual shuttering is enabled,
-        the user is responsible for triggering the shutter.
+        Shutter mode type case for manual shuttering. When manual shuttering is
+        enabled, the user is responsible for triggering the shutter.
     """
 
     AUTO = 0
@@ -406,8 +525,8 @@ class SeekCameraManager(object):
         ----------
         discovery_mode: int
             Integer indicating the type of devices to be discovered. It corresponds to
-            the enumerated IO type. That is, it is a value of IO type or it is a bitwise
-            OR combination of the enum values.
+            the enumerated IO type. That is, it is a value of IO type or it is a
+            bitwise OR combination of the enum values.
 
         Raises
         ------
@@ -558,6 +677,8 @@ class SeekCamera(object):
         Registers a user frame available callback function with the camera.
     shutter_trigger()
         Triggers the camera to shutter as soon as possible.
+    set_color_palette_data(palette, palette_data)
+        Sets the color palette data for a particular color palette.
     set_filter_state(filter_type, filter_state)
         Sets the state of an image processing filter.
     get_filter_state(filter_type)
@@ -768,9 +889,8 @@ class SeekCamera(object):
 
         WARNING: Function should not be called when a capture session is live.
 
-        WARNING: Function does not provide power failsafe firmware update on Micro Core
-        SPI cores. If a firmware update fails for one of those cores, please reload
-        firmware using the JTAG/SWD procedure.
+        NOTE: This function is not supported, and is not neccessary, for
+        Micro Core SPI cores.
 
         Parameters
         ----------
@@ -807,9 +927,9 @@ class SeekCamera(object):
         """Stores calibration data and pairs the camera.
 
         An optional callback can be used to provide progress updates.
-        Pairing refers to the process by which the sensor is associated with the host and
-        the embedded processor. The pairing process and requirements are highly dependent
-        on the characteristics of the camera and system.
+        Pairing refers to the process by which the sensor is associated with the host
+        and the embedded processor. The pairing process and requirements are highly
+        dependent on the characteristics of the camera and system.
 
         WARNING: Function should not be called when a capture session is live. Pairing
         commands are only applicable to Micro Cores.
@@ -817,8 +937,8 @@ class SeekCamera(object):
         Parameters
         ----------
         source_dir: str
-            If a false type, the calibration data is read from sensor flash. If non false
-            type, the calibration data is read from the filesystem.
+            If a false type, the calibration data is read from sensor flash. If non
+            false type, the calibration data is read from the filesystem.
         callback: callable
             Optional memory access callback that provides progress updates.
         user_data: any
@@ -848,10 +968,10 @@ class SeekCamera(object):
     def store_flat_scene_correction(self, fsc_id, callback=None, user_data=None):
         """Stores a flat scene correction (FSC).
 
-        The FSC is always stored to the host filesystem; it is also stored to the device
-        if supported. An optional callback can be used to provide progress updates. FSC
-        refers to the procedure used to correct non-uniformity in the thermal image
-        introduced by the OEMs manufacturing process.
+        The FSC is always stored to the host filesystem; it is also stored to the
+        device if supported. An optional callback can be used to provide progress
+        updates. FSC refers to the procedure used to correct non-uniformity in the
+        thermal image introduced by the OEMs manufacturing process.
 
         NOTE: The camera must start imaging to compute and store a FSC. The camera must
         stop imaging to persistently save a FSC.
@@ -889,8 +1009,8 @@ class SeekCamera(object):
     def delete_flat_scene_correction(self, fsc_id, callback=None, user_data=None):
         """Deletes a flat scene correction (FSC).
 
-        The FSC will be deleted from any location it was stored. An optional callback can
-        be used to provide progress updates.
+        The FSC will be deleted from any location it was stored. An optional callback
+        can be used to provide progress updates.
 
         NOTE: The camera must not be imaging to delete a FSC.
 
@@ -928,8 +1048,8 @@ class SeekCamera(object):
         """Loads application resources into host memory.
 
         The source region may either be the camera internal memory or the SDK internal
-        cache. Resources in each region must be <= 64KB. An optional callback can be used
-        to provide progress updates.
+        cache. Resources in each region must be <= 64KB. An optional callback can be
+        used to provide progress updates.
 
         WARNING: Function should not be called when a capture session is live.
 
@@ -973,9 +1093,9 @@ class SeekCamera(object):
     ):
         """Stores application resources to either the host or the device.
 
-        The source region is host memory. The destination region may either be the camera
-        internal memory or the SDK internal cache. Resources in each region must be
-        <= 64KB. An optional callback can be used to provoide progress updates.
+        The source region is host memory. The destination region may either be the
+        camera internal memory or the SDK internal cache. Resources in each region must
+        be <= 64KB. An optional callback can be used to provoide progress updates.
 
         WARNING: Function should not be called when a capture session is live.
 
@@ -1016,8 +1136,8 @@ class SeekCamera(object):
     def capture_session_start(self, frame_format):
         """Begins streaming frames of the specified formats from the camera.
 
-        Generally a frame available callback should be pre-registered in order to receive
-        frames, but doing so is not required.
+        Generally a frame available callback should be pre-registered in order to
+        receive frames, but doing so is not required.
 
         WARNING: Camera functions that interact with flash storage should not be called
         when a capture session is live.
@@ -1032,8 +1152,8 @@ class SeekCamera(object):
         Parameters
         ----------
         frame_format: int
-            Bitwise OR combination of the frame formats to output. The frame format types
-            are specified by SeekCameraFrameFormat.
+            Bitwise OR combination of the frame formats to output. The frame format
+            types are specified by SeekCameraFrameFormat.
 
         Raises
         ------
@@ -1060,8 +1180,8 @@ class SeekCamera(object):
     def register_frame_available_callback(self, callback, user_data=None):
         """Registers a user frame available callback function with the camera.
 
-        The callback is fired every time a new frame is available. There can only be one
-        registered frame available callback at a time.
+        The callback is fired every time a new frame is available. There can only be
+        one registered frame available callback at a time.
 
         Parameters
         ----------
@@ -1117,7 +1237,7 @@ class SeekCamera(object):
         if is_error(status):
             raise error_from_status(status)
 
-        return palette.value
+        return SeekCameraColorPalette(palette.value)
 
     @color_palette.setter
     def color_palette(self, palette):
@@ -1132,8 +1252,8 @@ class SeekCamera(object):
     def agc_mode(self):
         """Gets/sets the active AGC mode.
 
-        Settings are refreshed between frames. This method can only be performed after a
-        capture session has started.
+        Settings are refreshed between frames. This method can only be performed after
+        a capture session has started.
 
         Returns
         -------
@@ -1149,7 +1269,7 @@ class SeekCamera(object):
         if is_error(status):
             raise error_from_status(status)
 
-        return mode.value
+        return SeekCameraAGCMode(mode.value)
 
     @agc_mode.setter
     def agc_mode(self, mode):
@@ -1182,7 +1302,7 @@ class SeekCamera(object):
         if is_error(status):
             raise error_from_status(status)
 
-        return mode.value
+        return SeekCameraShutterMode(mode.value)
 
     @shutter_mode.setter
     def shutter_mode(self, mode):
@@ -1213,7 +1333,7 @@ class SeekCamera(object):
         if is_error(status):
             raise error_from_status(status)
 
-        return unit.value
+        return SeekCameraTemperatureUnit(unit.value)
 
     @temperature_unit.setter
     def temperature_unit(self, unit):
@@ -1243,9 +1363,9 @@ class SeekCamera(object):
         """Gets/sets the global scene emissivity.
 
         Emissivity is the measure of an object's ability to emit thermal radiation.
-        It may take on values in the closed interval [0,1] with floating point precision.
-        Settings are refreshed between frames. This method can only be performed after a
-        capture session has started.
+        It may take on values in the closed interval [0,1] with floating point
+        precision.  Settings are refreshed between frames. This method can only be
+        performed after a capture session has started.
 
         Returns
         -------
@@ -1304,6 +1424,48 @@ class SeekCamera(object):
         if is_error(status):
             raise error_from_status(status)
 
+    def set_color_palette_data(self, palette, palette_data):
+        """Sets the color palette data for a particular color palette.
+
+        Parameters
+        ----------
+        palette: SeekCameraColorPalette
+            Enumerated type corresponding to the color palette for which to set
+            the data.
+        palette_data: SeekCameraColorPalettteData
+            Color values used to colorize the thermal image.
+
+        Raises
+        ------
+        SeekCameraInvalidParameterError
+            1) If the palette is not of type SeekCameraColorPalette.
+            2) If the plaette data is not of type SeekCameraColorPaletteData.
+        SeekCameraError
+            If an error occurs.
+        """
+        if not isinstance(palette, SeekCameraColorPalette):
+            raise SeekCameraInvalidParameterError
+
+        if not isinstance(palette_data, SeekCameraColorPaletteData):
+            raise SeekCameraInvalidParameterError
+
+        data = (_clib.CSeekCameraColorPaletteDataEntry * len(palette_data))()
+
+        for index, value in enumerate(palette_data):
+            (b, g, r, a) = value
+
+            data[index] = (
+                ctypes.c_uint8(b),
+                ctypes.c_uint8(g),
+                ctypes.c_uint8(r),
+                ctypes.c_uint8(a),
+            )
+
+        status = _clib.cseekcamera_set_color_palette_data(self._camera, palette, data)
+
+        if is_error(status):
+            raise error_from_status(status)
+
     def set_filter_state(self, filter_type, filter_state):
         """Sets the state of an image processing filter.
 
@@ -1340,8 +1502,8 @@ class SeekCamera(object):
     def get_filter_state(self, filter_type):
         """Gets the state of an image processing filter.
 
-        Settings are refreshed between frames. This method can only be performed after a
-        capture session has started.
+        Settings are refreshed between frames. This method can only be performed after
+        a capture session has started.
 
         Parameters
         ----------
@@ -1373,8 +1535,8 @@ class SeekCamera(object):
 class SeekCameraFrameFormat(IntEnum):
     """Represents the types of output frame formats.
 
-    Multiple frame formats can be captured simultaneously. However only one Display frame
-    format and one Thermography frame format can exist in a capture session. The
+    Multiple frame formats can be captured simultaneously. However only one Display
+    frame format and one Thermography frame format can exist in a capture session. The
     exception is that grayscale can be captured along with another color Display format.
 
     NOTE: All format types are little endian byte order.
@@ -1410,9 +1572,11 @@ class SeekCameraFrameFormat(IntEnum):
         Color RGB565 format. To output RGB565 data, the SDK performs conversion from
         ARGB8888.
     COLOR_AYUV: int
-        Color AYUV format. To output AYUV data, the SDK performs conversion from ARGB8888.
+        Color AYUV format. To output AYUV data, the SDK performs conversion from
+        ARGB8888.
     COLOR_YUY2: int
-        Color YUY2 format. To output YUY2 data, the SDK performs conversion from ARGB8888.
+        Color YUY2 format. To output YUY2 data, the SDK performs conversion from
+        ARGB8888.
     """
 
     CORRECTED = 0x04
@@ -1484,7 +1648,8 @@ class SeekCameraFrame(object):
     def corrected(self):
         """Gets the corrected frame.
 
-        NOTE: The corrected format must have been specified in the capture session flags.
+        NOTE: The corrected format must have been specified in the capture session
+        flags.
 
         Returns
         -------
@@ -1614,7 +1779,8 @@ class SeekCameraFrame(object):
     def color_ayuv(self):
         """Gets the AYUV frame.
 
-        NOTE: The color AYUV format must have been specified in the capture session flags.
+        NOTE: The color AYUV format must have been specified in the capture session
+        flags.
 
         Returns
         -------
@@ -1632,7 +1798,8 @@ class SeekCameraFrame(object):
     def color_yuy2(self):
         """Gets the color YUY2 frame.
 
-        NOTE: The color YUY2 format must have been specified in the capture session flags.
+        NOTE: The color YUY2 format must have been specified in the capture session
+        flags.
 
         Returns
         -------
@@ -1663,8 +1830,8 @@ class SeekCameraFrame(object):
 class SeekCameraFrameHeader(object):
     """Represents a common header for the camera frame.
 
-    It is fixed size (2048 bytes) and byte aligned. It can be accessed in each individual
-    SeekFrame.
+    It is fixed size (2048 bytes) and byte aligned. It can be accessed in each
+    individual SeekFrame.
 
     Properties
     ----------
